@@ -88,6 +88,21 @@ def _create_projection(projection: str = None):
     return proj
 
 
+def _first_item(response):
+    if response is None or response.items is None or len(response.items) == 0:
+        return None
+    return response.items[0]
+
+
+def _create_spatial_ids(id: int = None, external_id: str = None):
+    _check_either_external_id(id, external_id)
+    if id is not None:
+        item = InternalIdDTO(id=id)
+    elif external_id is not None:
+        item = ExternalIdDTO(external_id=external_id)
+    return SpatialIdsDTO(items=[item])
+
+
 class CogniteGeospatialClient:
 
     """
@@ -126,9 +141,12 @@ class CogniteGeospatialClient:
 
         self.configuration.host = base_url + ":" + str(port)
 
+        self.project = project or os.getenv("COGNITE_PROJECT")
+        if self.project is None:
+            raise ValueError("Project must be provided")
+
         api_client = cognite.geospatial.internal.ApiClient(self.configuration)
         self.api = cognite.geospatial.internal.SpatialApi(api_client)
-        self.project = project or os.getenv("COGNITE_PROJECT")
         self.timeout = timeout
         self._make_new_loop()
 
@@ -197,30 +215,20 @@ class CogniteGeospatialClient:
         return future_cell[0].result()
 
     @gen.coroutine
-    def get_spatial_info_async(self, id: int = None, external_id: str = None, project: str = None):
+    def get_spatial_info_async(self, id: int = None, external_id: str = None):
         """Retrieves spatial item information by internal ids or external ids.
         """
-        _check_either_external_id(id, external_id)
-        project = self._get_project(project)
-        if id is not None:
-            item = InternalIdDTO(id=id)
-        elif external_id is not None:
-            item = ExternalIdDTO(external_id=external_id)
-        spatial_by_ids = SpatialIdsDTO(items=[item])
+        spatial_by_ids = _create_spatial_ids(id, external_id)
         try:
-            response = yield self.api.by_ids_spatial_items(project, spatial_by_ids)
-            if response is not None:
-                items = response.items
-                if items is not None and len(items) > 0:
-                    return items[0]
-            return None
+            response = yield self.api.by_ids_spatial_items(self.project, spatial_by_ids)
+            return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
 
-    def get_spatial_info(self, id: int = None, external_id: str = None, project: str = None):
+    def get_spatial_info(self, id: int = None, external_id: str = None):
         """Retrieves spatial item information by internal ids or external ids.
         """
-        run_func = partial(self.get_spatial_info_async, id, external_id, project)
+        run_func = partial(self.get_spatial_info_async, id, external_id)
         item = self._run_sync(run_func, self.timeout)
         return item
 
@@ -228,19 +236,10 @@ class CogniteGeospatialClient:
     def delete_spatial_async(self, id: int = None, external_id: str = None):
         """Delete spatial item by internal ids or external ids.
         """
-        _check_either_external_id(id, external_id)
-        if id is not None:
-            item = InternalIdDTO(id=id)
-        elif external_id is not None:
-            item = ExternalIdDTO(external_id=external_id)
-        spatial_by_ids = SpatialIdsDTO(items=[item])
+        spatial_delete_ids = _create_spatial_ids(id, external_id)
         try:
-            response = yield self.api.delete_spatial(self.project, spatial_by_ids)
-            if response is not None:
-                items = response.items
-                if items is not None and len(items) > 0:
-                    return items[0]
-            return None
+            response = yield self.api.delete_spatial(self.project, spatial_delete_ids)
+            return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
 
@@ -252,17 +251,16 @@ class CogniteGeospatialClient:
         return item
 
     @gen.coroutine
-    def get_spatial_async(self, id: int = None, external_id: str = None, project: str = None):
+    def get_spatial_async(self, id: int = None, external_id: str = None):
         """Retrieves spatial item data by internal ids or external ids.
         """
         _check_either_external_id(id, external_id)
-        project = self._get_project(project)
         if id is not None:
             item = InternalIdDTO(id=id)
         elif external_id is not None:
             item = ExternalIdDTO(external_id=external_id)
 
-        spatial_item = yield self.get_spatial_info_async(id=id, external_id=external_id, project=project)
+        spatial_item = yield self.get_spatial_info_async(id=id, external_id=external_id, project=self.project)
         if spatial_item is None:
             return None
 
@@ -284,12 +282,12 @@ class CogniteGeospatialClient:
         )
 
         try:
-            response = yield self.api.get_spatial_items_data_names(project, item)
+            response = yield self.api.get_spatial_items_data_names(self.project, item)
             if response is not None:
 
                 for data_item in response.items:
                     data_request = SpatialDataRequestDTO(spatial_id=item, name=data_item.name)
-                    data = yield self.api.get_spatial_items_data(project, data_request)
+                    data = yield self.api.get_spatial_items_data(self.project, data_request)
                     if data is not None and len(data.items) > 0:
                         ditem = data.items[0]
                         byte_buffer = base64.urlsafe_b64decode(ditem.value)
@@ -311,41 +309,30 @@ class CogniteGeospatialClient:
 
         return spatial_object
 
-    def get_spatial(self, id: int = None, external_id: str = None, project: str = None):
+    def get_spatial(self, id: int = None, external_id: str = None):
         """Retrieves spatial item data by internal ids or external ids.
         """
-        run_func = partial(self.get_spatial_async, id, external_id, project)
+        run_func = partial(self.get_spatial_async, id, external_id)
         result = self._run_sync(run_func, self.timeout)
         return result
 
     @gen.coroutine
-    def get_coverage_async(self, id: int = None, external_id: str = None, projection: str = None, project: str = None):
+    def get_coverage_async(self, id: int = None, external_id: str = None, projection: str = None):
         """Retrieves spatial item information by internal ids or external ids.
         """
-        _check_either_external_id(id, external_id)
-        project = self._get_project(project)
-        if id is not None:
-            item = InternalIdDTO(id=id)
-        elif external_id is not None:
-            item = ExternalIdDTO(external_id=external_id)
-        spatial_by_ids = SpatialIdsDTO(items=[item])
-
+        spatial_by_ids = _create_spatial_ids(id, external_id)
         proj = _create_projection(projection)
         spatialite_projection = SpatialItemsProjectionDTO(ids=spatial_by_ids, projection=proj)
         try:
-            response = yield self.api.get_spatial_coverage(project, spatialite_projection)
-            if response is not None:
-                items = response.items
-                if items is not None and len(items) > 0:
-                    return items[0]
-            return None
+            response = yield self.api.get_spatial_coverage(self.project, spatialite_projection)
+            return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
 
-    def get_coverage(self, id: int = None, external_id: str = None, projection: str = None, project: str = None):
+    def get_coverage(self, id: int = None, external_id: str = None, projection: str = None):
         """Retrieves spatial item information by internal ids or external ids.
         """
-        run_func = partial(self.get_coverage_async, id, external_id, projection, project)
+        run_func = partial(self.get_coverage_async, id, external_id, projection)
         item = self._run_sync(run_func, self.timeout)
         return item
 
@@ -361,11 +348,9 @@ class CogniteGeospatialClient:
         crs: str = None,
         projection: str = None,
         limit: int = 10,
-        project: str = None,
     ):
         """Searches and returns the spatial items based on resource type content or coordinates.
         """
-        project = self._get_project(project)
         spatial_filter = None
         if geography is not None:
             geometry = self._create_geometry(geography=geography)
@@ -385,7 +370,7 @@ class CogniteGeospatialClient:
         )
 
         try:
-            response = yield self.api.search_spatial(project, spatial_search_request_dto=spatial_search_request)
+            response = yield self.api.search_spatial(self.project, spatial_search_request_dto=spatial_search_request)
             if response is not None:
                 return response.items
             return None
@@ -403,7 +388,6 @@ class CogniteGeospatialClient:
         crs: str = None,
         projection: str = None,
         limit: int = 10,
-        project: str = None,
     ):
         """Searches and returns the spatial items based on resource type content or coordinates.
         """
@@ -418,7 +402,6 @@ class CogniteGeospatialClient:
             crs,
             projection,
             limit,
-            project,
         )
         result = self._run_sync(run_func, self.timeout)
         return result
@@ -433,11 +416,9 @@ class CogniteGeospatialClient:
         crs: str = None,
         projection: str = None,
         limit: int = 10,
-        project: str = None,
     ):
         """Selects features in the input feature layer within or contained by features in the selecting features layer.
         """
-        project = self._get_project(project)
         geometry = self._create_geometry(id, external_id, geography)
         proj = _create_projection(projection)
         if distance is None:
@@ -456,7 +437,7 @@ class CogniteGeospatialClient:
         spatial_search_request = SpatialSearchRequestDTO(limit=limit, spatial_filter=spatial_filter, crs=crs)
 
         try:
-            response = yield self.api.search_spatial(project, spatial_search_request_dto=spatial_search_request)
+            response = yield self.api.search_spatial(self.project, spatial_search_request_dto=spatial_search_request)
             if response is not None:
                 return response.items
             return None
@@ -472,13 +453,10 @@ class CogniteGeospatialClient:
         crs: str = None,
         projection: str = None,
         limit: int = 10,
-        project: str = None,
     ):
         """Selects features in the input feature layer within or contained by features in the selecting features layer.
         """
-        run_func = partial(
-            self.find_within_async, id, external_id, geography, distance, crs, projection, limit, project
-        )
+        run_func = partial(self.find_within_async, id, external_id, geography, distance, crs, projection, limit)
         result = self._run_sync(run_func, self.timeout)
         return result
 
@@ -491,12 +469,10 @@ class CogniteGeospatialClient:
         crs: str = None,
         projection: str = None,
         limit: int = 10,
-        project: str = None,
     ):
 
         """The result is identical to Within except when the feature in the input feature layer intersects the boundary of the feature in the selecting features layer; then it is not selected.
         """
-        project = self._get_project(project)
         geometry = self._create_geometry(id, external_id, geography)
         proj = _create_projection(projection)
         spatial_filter = SpatialFilterObject(
@@ -504,7 +480,7 @@ class CogniteGeospatialClient:
         )
         spatial_search_request = SpatialSearchRequestDTO(limit=limit, spatial_filter=spatial_filter, crs=crs)
         try:
-            response = yield self.api.search_spatial(project, spatial_search_request_dto=spatial_search_request)
+            response = yield self.api.search_spatial(self.project, spatial_search_request_dto=spatial_search_request)
             if response is not None:
                 return response.items
             return None
@@ -519,13 +495,10 @@ class CogniteGeospatialClient:
         crs: str = None,
         projection: str = None,
         limit: int = 10,
-        project: str = None,
     ):
         """The result is identical to Within except when the feature in the input feature layer intersects the boundary of the feature in the selecting features layer; then it is not selected.
         """
-        run_func = partial(
-            self.find_within_completely_async, id, external_id, geography, crs, projection, limit, project
-        )
+        run_func = partial(self.find_within_completely_async, id, external_id, geography, crs, projection, limit)
         result = self._run_sync(run_func, self.timeout)
         return result
 
@@ -555,9 +528,7 @@ class CogniteGeospatialClient:
         create_spatial_items = CreateSpatialItemsDTO(items=[spatial_item])
         try:
             response = yield self.api.create_spatial(self.project, create_spatial_items)
-            if response is not None:
-                return response.items
-            return None
+            return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
 
@@ -686,13 +657,7 @@ class CogniteGeospatialClient:
     def calculate_spatial_coverage_async(self, id: int = None, external_id: str = None):
         """Calculate spatial item coverage by internal ids or external ids.
         """
-        _check_either_external_id(id, external_id)
-        if id is not None:
-            item = InternalIdDTO(id=id)
-        elif external_id is not None:
-            item = ExternalIdDTO(external_id=external_id)
-        spatial_by_ids = SpatialIdsDTO(items=[item])
-
+        spatial_by_ids = _create_spatial_ids(id, external_id)
         try:
             response = yield self.api.calculate_spatial_coverage(self.project, spatial_by_ids)
             return response
@@ -782,8 +747,3 @@ class CogniteGeospatialClient:
         return cognite.geospatial.internal.GeometryDTO(
             id=id, external_id=external_id, wkt=geography, local_vars_configuration=self.configuration
         )
-
-    def _get_project(self, project: str = None):
-        if project is None and self.project is None:
-            raise ValueError("Project must be provided")
-        return project if project is not None else self.project
