@@ -93,6 +93,8 @@ class SpatialObject:
                 data = np.stack((x, y), axis=-1)
             else:
                 data = np.stack((x, y, z), axis=-1)
+            if active is None:
+                return data
             active = active[: len(data)]
             return data[active]
         else:
@@ -114,8 +116,6 @@ class SpatialObject:
 
     def grid(self):
         if self.geometry.type == SpatialTypesDTO.RASTER:
-            width = self.width()
-            height = self.height()
             active = self.__getitem__("Active")
             x = self.__getitem__("X")
             y = self.__getitem__("Y")
@@ -124,13 +124,29 @@ class SpatialObject:
                 points = np.stack((x, y), axis=-1)
             else:
                 points = np.stack((x, y, z), axis=-1)
-            size = min(len(active), len(points))
-            active_indx = np.argwhere(active[:size] == True)
-            data = np.ndarray(shape=(width, height, 3), dtype=np.double)
-            for i in active_indx:
-                r = int(i % height)
-                c = int((i - r) / height)
-                data[c, r] = points[i]
+
+            if active is None:
+                rows = self.__getitem__("Row")
+                columns = self.__getitem__("Column")
+                if rows is None or columns is None:
+                    return None
+                height = rows.max() - rows.min() + 1
+                width = columns.max() - columns.min() + 1
+                data = np.ndarray(shape=(height, width, points.shape[1]), dtype=np.double)
+                for i in range(len(points)):
+                    r = rows[i] - rows.min()
+                    c = columns[i] - columns.min()
+                    data[r, c] = points[i]
+            else:
+                width = self.width()
+                height = self.height()
+                data = np.ndarray(shape=(width, height, points.shape[1]), dtype=np.double)
+                size = min(len(active), len(points))
+                active_indx = np.argwhere(active[:size] == True)
+                for i in active_indx:
+                    r = int(i % height)
+                    c = int((i - r) / height)
+                    data[c, r] = points[i]
 
             return data
         return None
